.. _theory:

Theory
======

The theory of the model is explained here. For more details, please refer to [#vf_paper]_ .

Contents:

.. toctree::
   :maxdepth: 2

   intro
   view_factors
   problem_formulation


.. rubric:: Footnotes

.. [#vf_paper] Anoma, M., Jacob, D., Bourne, B.C., Scholl, J.A., Riley, D.M. and Hansen, C.W., 2017. View Factor Model and Validation for Bifacial PV and Diffuse Shade on Single-Axis Trackers. In 44th IEEE Photovoltaic Specialist Conference.
